@@ -88,7 +88,7 @@ class GridFile(object):
             if mode == "r":
                 raise IOError("No such file: %r" % file_spec)
             file_spec["length"] = 0
-            file_spec["uploadDate"] = datetime.datetime.now()
+            file_spec["uploadDate"] = datetime.datetime.utcnow()
             file_spec.setdefault("chunkSize", 256000)
             self.__id = self.__collection.files.insert(file_spec)["_id"]
 
